// This .do-file is intended to be compiled into a smcl presentation using:
// smclpres
// =============================================================================

//layout toc        link(subsubsection) title(subsubsection)
//layout toc        secbold
//layout topbar     on 
//layout bottombar  arrow 
//layout title      center nothline nobhline

//file ieo.dta
//file infmort.dta
//file ZA4578_v1-0-0.dta
//file ecassess.dta
//file uni.dta
//file voter.dta
//file uni.gph
//file scheme_lean.hlp
//file scheme_lean1.hlp
//file scheme_lean2.hlp
//file scheme-lean1.scheme
//file scheme-lean2.scheme
//file grc1leg.hlp
//file grc1leg.ado

/*toctitle 
Graphics in Stata
toctitle*/

/*toctxt

{center:Maarten Buis}
{center:University of Konstanz}

{center:maarten.buis@uni.kn}
toctxt*/

//section Main graph types

//slide ------------------------------------------------------------------------
//title Two main types

/*txt
{pstd}{ul:A scatter plot:}{p_end}
txt*/
//ex
sysuse auto, clear
twoway scatter price mpg
//endex
/*txt
{pstd}Notice that the axes are labeled. Where did these labels come from?{p_end}

{pstd}{ul:A line plot}{p_end}
txt*/
//ex
sysuse uslifeexp, clear
twoway line le year
//endex
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title By default graphs are overwritten, can we change that?

//ex
sysuse auto, clear
twoway scatter price mpg, name(scatter, replace)
sysuse uslifeexp, clear
twoway line le year, name(line, replace)
//endex
//graph scatter
//graph line
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  twoway function
/*txt
{pstd}With {cmd:twoway function} we can draw a function, so we don't need any
data for it{p_end}
txt*/
//ex
        graph drop _all
        twoway function y = x,       ///
            aspect(1)                ///
            name(function1, replace)
//endex
//graph function1

//ex
        twoway function y = x^2,     ///
            name(function2, replace)
//endex
//graph function2

/*txt
{pstd}By default the range for x that is plotted is [0, 1], but this can be 
changed with the {cmd:range()} option. {p_end}
txt*/

//ex
        twoway function y = x^2,     ///
            range(-10 10)            ///
            name(function3, replace)
//endex
//graph function3

/*txt
{pstd}The option {cmd:range()} expects numbers, but sometimes we want to give
it the result of calculations.{p_end}

{pstd}You can include such computation between {cmd:`=} and {cmd:'}.{p_end}
txt*/
//ex
        twoway function y = sin(x),   ///
            range(0 `=3*_pi')         ///
            yline(0)                  ///
            name(function4, replace)
//endex
//graph function4

/*txt
{center:{bf:Try it yourself}}

{pstd}
You are working with a indicator (dummy) variable and you vaguely remembered that
the variance of such a variable is {it:p*(1-p)}, where {it:p} is the proportion 
of successes (which also happens to be the mean). You are curious how the variance
changes when the mean of a dummy variable changes, so you decide to use 
{cmd:twoway function} to show you the graph.

{pstd}
//ho_ignore {stata doedit function_sol.do : Solution}
txt*/
//apcodefile function_sol.do
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  Area graphs

/*txt
{pstd}{cmd: twoway area} draws an area from the bottom of the graph till the first 
variable named.{p_end}
txt*/

//ex
        graph drop _all
        sysuse uslifeexp, clear
        twoway area le year, ylab(0(20)80) ///
            name(area, replace)
//endex
//graph area

/*txt
{pstd}{cmd:twoway rarea} draws an area from the first variable named till the 
second variable named.{p_end}

{pstd}It is useful for drawing confidence intervals{p_end}
txt*/

//ex
        sysuse uslifeexp, clear
        fp <year> : reg le <year> if year != 1918
        predictnl lehat = xb(), ci(lb ub)
        twoway rarea lb ub year, ///
            name(rarea1, replace)
//endex
//graph rarea1

/*txt
{pstd}It to has the {cmd:cmissing()} option to let you decide how to deal with
missing values{p_end}
txt*/

//ex
        twoway rarea lb ub year, ///
            cmissing(n)          ///
            name(rarea2, replace)
//endex
//graph rarea2

/*txt
{pstd}The sort order in the data is important. If you mess that up you get 
modern art{p_end}
txt*/

//ex
        gen u = runiform()
        sort u
        twoway rarea lb ub year, ///
            name(rarea3, replace)
//endex
//graph rarea3

/*txt
{pstd}
You can fix that with the {cmd:sort} option.
txt*/

//ex
        twoway rarea lb ub year, ///
            sort                 ///
            name(rarea4, replace)
//endex
//graph rarea4

//endslide ---------------------------------------------------------------------


//slide ------------------------------------------------------------------------
//title  Bar graphs and variations thereof

/*txt
{pstd}{cmd:twoway bar} is a low level way of making bar graphs{p_end}

{pstd}Low level means that you need to do more data preparation, but in return
get a lot of freedom{p_end}

{pstd}The easier but less flexible alternative would be {help graph bar}{p_end}
txt*/
//ex
        graph drop _all
        sysuse auto, clear
        contract rep78
        list
        twoway bar _freq rep78, ///
            name(bar1, replace)
//endex
//graph bar1

//ex
        twoway bar _freq rep78, ///
            barw(.5)            ///
            name(bar2, replace)
//endex
//graph bar2

/*txt
{pstd}
What if we want to look at the distribution of repair status for foreign 
and domestic cars?
txt*/

//ex
sysuse auto, clear
contract rep78 foreign
list
separate _freq , by(foreign) veryshortlabel
twoway bar _freq? rep78, name(bar3a, replace)
//endex
//graph bar3a

/*txt
{pstd}
Close, but not quite. Lets nudge the foreign cars a bit to the right and the 
domestic cars a bit to the left.
txt*/

//ex
gen x = cond(foreign==1,rep78 + .2, rep78 - .2)
twoway bar _freq? x, barw(.4 .4) ///
    xtitle(repair status)        ///
    ytitle(frequency)            ///
    name(bar3b, replace)
//endex
//graph bar3b

/*txt
{pstd}Instead of bars you plot spikes.{p_end}
txt*/

//ex
        twoway spike _freq x, ///
            name(spike, replace)
//endex
//graph spike

/*txt
{pstd}Or draw a symbol on the top of the spikes{p_end}

{pstd}This is a nice graph to display summary statistics for a set of variables.{p_end}
txt*/

//ex
        twoway dropline _freq x, ///
            name(dropline1, replace)
//endex
//graph dropline1

/*txt
{pstd}Particulary in horizontal mode.{p_end}
txt*/

//ex
        twoway dropline _freq x,     ///
            horizontal               ///
            name(dropline2, replace)
//endex
//graph dropline2

/*txt 
{center:{bf:Try it yourself}}


{pstd}
Below we make a dataset containing for each industry the mean wage. Graph this 
as horizontal droplines.
txt*/

//ex
sysuse nlsw88, clear
collapse (mean) wage, by(industry)
egen Industry = axis(wage) if industry < ., label(industry)
list
list, nolabel
//endex

/*txt
{pstd}
//ho_ignore {stata doedit dropline_sol.do : Solution}
txt*/
//apcodefile dropline_sol.do
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  Arrows

/*txt
{pstd}You can also draw arrows.{p_end}

{pstd}This needs a y and x coordinate for the starting point and a y and x
coordinate for the end point (arrow head).
txt*/

//ex
        graph drop _all
        use ecassess, clear
        gen sort = _n
        tsset sort
        twoway pcarrow L.own L.brd own brd,                     ///
            ytitle("assessment of own economic position")       ///
            xtitle("assessment of Germany's economic position") ///
            name(pcarrow1, replace)             
//endex
//graph pcarrow1

//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  Contour plots
/*txt
{pstd}We can plot 3D graphs as a contour plot{p_end}

{pstd}If there is no data for a part of the graph, then it will use interpolation{p_end}

{pstd}This can be slow{p_end}

{pstd}Since we are plotting the results from a regression model, we can much more 
quickly do the interpolation ourselves{p_end}

{pstd} This is what I am doing in the lines between {cmd:drop _all} and {cmd: predict}{p_end}
txt*/

//ex
        graph drop _all
        sysuse nlsw88, clear
        reg wage c.ttl_exp##c.ttl_exp##c.tenure##c.tenure
        drop _all
        set obs 30
        gen ttl_exp = _n - 1
        gen tenure  = _n - 1 if _n < 27
        fillin ttl_exp tenure
        drop if tenure == .
        predict wagehat
        twoway contour wagehat ttl_exp tenure, ///
            name(contour1, replace)
//endex
//graph contour1

/*txt
{pstd}We can see finer details when we increase the number of contourlines{p_end}
txt*/

//ex
        twoway contour wagehat ttl_exp tenure, ///
            name(contour2, replace )           ///
            ccuts(-6(2)16)
//endex
//graph contour2

//endslide ---------------------------------------------------------------------


//section The main elements of a graph

//subsection titles

//slide ------------------------------------------------------------------------
//title Main title
/*txt
{pstd}We can add a title to our graph with the {cmd:title()} option{p_end}
txt*/

//ex
graph drop _all
sysuse auto, clear
scatter price mpg, name(price, replace) ///
        title("Association between price and mileage")
//endex
//graph price

/*txt
{pstd}If the title is too long we can add line breaks {p_end}
txt*/

//ex
scatter price mpg, name(price2, replace) ///
        title("Association between price" "and mileage")
//endex
//graph price2
/*txt
{pstd}You can change the position of the title with the {cmd:pos()} 
sub-option.{p_end}
txt*/

//ex
scatter price mpg, name(price3, replace) ///
        title("Association between price and mileage", ///
              pos(11))
//endex
//graph price3

/*txt
{pstd}Notice that title is centered on the graph area, you can change that with 
the {cmd:span} sub-option{p_end}
txt*/
//ex
scatter price mpg, name(price4, replace) ///
        title("Association between price and mileage", ///
              pos(11) span)
//endex
//graph price4

/*txt
{pstd}Much of what is possible with graph titles is discussed in {help title options}{p_end}
txt*/



//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title Fonts and symbols

/*txt
{pstd}We can also use different fonts{p_end}

{pstd}This is discussed in {help graph text}{p_end}
txt*/

//ex
graph drop _all
scatter price mpg, name(fonts, replace) ///
        title("{it:Association} between {bf:price} and {bf:mileage}")
//endex
//graph fonts

/*txt
{pstd}You can also add symbols{p_end}
txt*/
//ex
scatter price mpg, name(symbols, replace) ///
        title("y = {&beta}{sub:0} + {&beta}{sub:1} x{sub:1} + {&epsilon}")
//endex
//graph symbols

/*txt

{center:{bf:Try it yourself}}

{pstd}
Use uni.dta and recreate {stata graph use uni.gph:this graph}.

{pstd}
//ho_ignore {stata doedit title_sol.do : Solution}
txt*/
//apcodefile title_sol.do



//endslide ---------------------------------------------------------------------


//slide ------------------------------------------------------------------------
//title Axis titles

/*txt
{pstd}By default the axis titles are the variable labels{p_end}

{pstd}If there is no variable label the variable name is chosen{p_end}

{pstd}You can change those defaults using the {cmd:xtitle()} and {cmd:ytitle()}
       options.{p_end}
txt*/
//ex
graph drop _all
sysuse auto, clear
scatter price mpg, name(ytitle, replace) ///
        ytitle("Something else")
//endex
//graph ytitle
/*txt
{pstd}Line breaking, fonts and symbols work just as in the main title.{p_end}

{pstd}You can also suppres the disply of title{p_end}
txt*/
//ex
scatter price mpg, name(noytitle, replace) ///
        ytitle("")
//endex
//graph noytitle

//endslide ---------------------------------------------------------------------


//slide ------------------------------------------------------------------------
//title Notes

/*txt
{pstd}You can add a note underneath the graph using the {cmd:note()} option{p_end}
txt*/
//ex
sysuse auto, clear
scatter price mpg, name(note1, replace) ///
        note("Source: Consumer Reports")
//endex
//graph note1

/*txt
{pstd}Line breaking, fonts, symbols, and suppressing a note work just as before.{p_end}

{pstd}By default the note is alligned on the plot area, you can override that 
using the {cmd:span} sub-option.{p_end}
txt*/ 
//ex
sysuse auto, clear
scatter price mpg, name(note2, replace) ///
        note("Source: Consumer Reports", span)
//endex
//graph note2

//endslide ---------------------------------------------------------------------

//subsection axis
//slide ------------------------------------------------------------------------
//title axis labels
/*txt
{pstd}You can add change the axis label using the {cmd:xlab()} and {cmd:ylab()} 
options{p_end}

{pstd}This is doucmenten in {help axis label options}{p_end}
txt*/
//ex
graph drop _all
sysuse auto, clear
scatter price weight, name(ylab1, replace) 
scatter price weight, name(ylab2, replace) ///
        ylab(5000(5000)15000)
//endex
//graph ylab1
//graph ylab2

//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title Using value labels to label the axes
/*txt
{pstd}For categorical variables it often makes sense to use the value labels 
as axis labels instead of the numerical values{p_end}

{pstd}You can do this with the {cmd:valuelabel} suboption within {cmd:ylab} or {xlab}{p_end}

{pstd}This is doucmenten in {help axis label options}{p_end}
txt*/
//ex
sysuse pop2000
twoway scatter agegrp femtotal, ///
     ylab(1/17, valuelabel)     ///
     xlab(0(2e6)10e6)           ///
     name(axlab1, replace)
//endex
//graph axlab1

/*txt
{pstd}2e6 is 2,000,000. I find that notation convenient for large numbers as it 
prevents me from adding a 0 too many or too few.
txt*/

//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title Make your own axis labels

/*txt
{pstd}
You can give some or all axis label their own label.
txt*/

//ex
graph drop _all
sysuse auto, clear
sum price if weight < ., meanonly
local m = r(mean)
twoway scatter price weight,               ///
    ylab( 5000 `m' "mean" 10000 15000 )    /// 
    ytitle("Price (US {c S|})")            ///
     name(axlab2, replace)
//endex
//graph axlab2

/*txt
{pstd}
The 000 in each label is a bit double, so use this trick to move those into the 
ytitle
txt*/

//ex
sum price if weight < ., meanonly
local m = r(mean)
twoway scatter price weight, ///
    ylab( 5000 "5"           ///
         `m'   "mean"        ///
         10000 "10"          ///
         15000 "15" )        ///
     name(axlab3, replace)   ///
     ytitle("Price (1000s of US {c S|})")      
//endex
//graph axlab3

//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title logarithmic scale

/*txt
{pstd}
Sometimes variables have a range that cover multiple orders of magnitude.

{pstd}
In those cases the action at the lower orders of magnitude tend to get hiden 
by the range.
txt*/

//ex
graph drop _all
use infmort, clear
scatter infmort gdppc, ///
    name(log1, replace)
//endex
//graph log1

/*txt
{pstd}
Logarithmic scale are a way to solve that

{pstd}
You can do that by adding the {cmd:xscale(log)} or {cmd:yscale(log)} option.

{pstd}
This is documented in {help axis scale option:help axis scale option}
txt*/

//ex
scatter infmort gdppc,      ///
    yscale(log) xscale(log) ///
    name(log2, replace)
//endex
//graph log2

/*txt
{pstd}
We typically need to change the axis labels after that.

{pstd}
{cmd:1e3} is 1000. I often use that notation in this circumstance because this 
way I find it easy to avoid miscounting the number of zeros.
txt*/

//ex
scatter infmort gdppc,      ///
    yscale(log) xscale(log) ///
    name(log3, replace)     ///
    ylab( 2 5 10 20 50 100 200) ///
    xlab(1e3 1e4 1e5)
//endex
//graph log3

/*txt
{pstd}
10,000 is often easier to read than 10000. You can do that by displaying a number
in Stata with the format %9.0gc (c for comma)

{pstd}
Axis labels allow for the format() option with which you can choose the format.
txt*/

//ex
scatter infmort gdppc,                ///
    yscale(log) xscale(log)           ///
    name(log4, replace)               ///
    ylab( 2 5 10 20 50 100 200)       ///
    xlab(1e3 1e4 1e5, format(%9.0gc))
//endex
//graph log4

/*txt
{pstd}
Alternatively, you can display them as powers of 10.
txt*/


//ex
scatter infmort gdppc,          ///
    yscale(log) xscale(log)     ///
    name(log5, replace)         ///
    ylab( 2 5 10 20 50 100 200) ///
    xlab(1e3 "10{sup:3}"        ///
         1e4 "10{sup:4}"        ///
         1e5 "10{sup:5}" ) 
//endex
//graph log5
//endslide ---------------------------------------------------------------------


//slide ------------------------------------------------------------------------
//title axis range

/*txt
{pstd}You can increase the range of the axis using the {cmd:yscale(range())} and {cmd:xscale(range())} 
options{p_end}

{pstd}This is doucmenten in {help axis scale options}{p_end}
txt*/

//ex
        graph drop _all
        sysuse auto, clear
        scatter price mpg, name(yrange1, replace) 
        scatter price mpg, name(yrange2, replace) ///
                yscale(range(0 20000))
//endex
//graph yrange1
//graph yrange2
/*txt
{pstd}Notice that you cannot decrease the range of the axis to be be less than 
       the range of the data{p_end}

{pstd}To cut off a part of the data you need to use an {cmd:if} condition{p_end}
txt*/

//ex
        scatter price mpg if price < 10000, name(yrange3, replace) 
//endex
//graph yrange3

/*txt
{center:{bf:Try it yourself}}

{pstd}
We have made a graph using uni.dta in the previous Do it yourself. Now it is 
to change the axes. The y-axis would be better off as a log scale. It would also
help to have a comma seperate 1000s. The x-scale ranges till 2050, and we really
don't have data that far in the future.

{pstd}
//ho_ignore {stata doedit axis_sol.do : Solution}
txt*/
//apcodefile axis_sol.do

//endslide ---------------------------------------------------------------------


//subsection legend


//slide ------------------------------------------------------------------------
//title  using separate

/*txt
{pstd}There is something funny going on in the graph below. We might want
to check whether there are different groups of cars.{p_end}
txt*/

//ex
        graph drop _all
        sysuse auto, clear
        scatter price weight, name(noseparate, replace)
//endex
//graph noseparate

/*txt
{pstd}With {cmd:separate} we create two price variables:{p_end}

{pstd}price0 contains the price if the car is domestic and otherwise it 
contains a missing value.{p_end}
{pstd}price1 contains the price if the car is foreign and otherwise it 
contains a missing value.{p_end}
txt*/

//ex
        separate price, by(foreign)
        list foreign price price0 price1 in 45/55
        scatter price0 price1 weight, name(separate, replace)
//endex
//graph separate

/*txt
{pstd}Notice that by default the legend uses the variable labels, and that the 
default variable labels are not quite suitable for this purpose{p_end}

{pstd}
The easiest solution is to add the {cmd:veryshortlabel} option to {cmd:separate},
but here we will ignore that to show how you can change the legend yourself.
txt*/

//endslide ---------------------------------------------------------------------


//slide ------------------------------------------------------------------------
//title  Changing the content of the legend

/*txt
{pstd}In this case, the variable labels are not very pretty, so we may want
to change those{p_end}

{pstd}The easiest way is to do that with the {cmd:order()} option{p_end}

{pstd}This is documented in {help legend options}{p_end}
txt*/

//ex
        graph drop _all
        scatter price0 price1 weight,   ///
            legend(order(1 "Domestic"   ///
                         2 "Foreign" )) ///
            name(legend1, replace)
//endex
//graph legend1

/*txt
{pstd}We can break longer lines in the same way as we did with titles.{p_end}
txt*/

//ex
        scatter price0 price1 weight,          ///
            legend(order(1 "Domestic" "cars"   ///
                         2 "Foreign" "cars" )) ///
            name(legend2, replace)
//endex
//graph legend2

//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  Position of the legend

/*txt
{pstd}In the lean1 style the legend is put in the bottom right corner outside 
the graph.{p_end}

{pstd}We can change this using the {cmd:pos()} option.{p_end}
txt*/

//ex
        scatter price0 price1 weight,   ///
            legend(order(1 "Domestic"   ///
                         2 "Foreign" )  ///
                   pos(6) )             /// <-- new
            name(legend3, replace)
//endex
//graph legend3

/*txt
{pstd}If we put the legend at the bottom, then it makes sense to spread the
legend over two columns.{p_end}

{pstd}This can be achieved with the {cmd:cols()} option.{p_end}
txt*/

//ex
        scatter price0 price1 weight,   ///
            legend(order(1 "Domestic"   ///
                         2 "Foreign" )  ///
                   pos(6) cols(2))      /// <-- new
            name(legend4, replace)
//endex
//graph legend4

/*txt
{pstd}We can put the legend inside the plotregion using the {cmd:ring(0)} option{p_end}
txt*/

//ex
        scatter price0 price1 weight,   ///
            legend(order(1 "Domestic"   ///
                         2 "Foreign" )  ///
                   pos(5) ring(0) )     /// <-- new
            name(legend5, replace)
//endex
//graph legend5

/*txt
{pstd}It now makes sense to put an outline around the legend.{p_end}
txt*/

//ex
        scatter price0 price1 weight,      ///
            legend(order(1 "Domestic"      ///
                         2 "Foreign" )     ///
                   pos(5) ring(0)          ///
                   region(style(outline))) /// <-- new
            name(legend6, replace)
//endex
//graph legend6

//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  Titles within the legend

/*txt
{pstd}We can add a title to the legend.{p_end}

{pstd}There is a {cmd:title()} sub-option for {cmd:legend()}, but that is 
typically too large.{p_end}

{pstd}It is usually better to use the {cmd:subtitle()} sub-option.{p_end}
txt*/

//ex
        graph drop _all
        scatter price0 price1 weight,   ///
            legend(order(1 "Domestic"   ///
                         2 "Foreign" )  ///
                   subtitle("legend")   /// 
                   pos(6) cols(2))      ///
            name(legendtitle1, replace)
//endex
//graph legendtitle1

/*txt
{pstd}Alternatively, you can add text in the {cmd:order()} sub-option.{p_end}
txt*/

//ex
        graph drop _all
        scatter price0 price1 weight,   ///
            legend(order(- "Legend"     ///
                         1 "Domestic"   ///
                         2 "Foreign" )  ///
                   pos(6) cols(2))      ///
            name(legendtitle2, replace)
//endex
//graph legendtitle2

/*txt
{pstd}We can let the "title" have its own line by adding an empty text.{p_end}
txt*/

//ex
        scatter price0 price1 weight,   ///
            legend(order(- "Legend"     ///   
                         - " "          ///
                         1 "Domestic"   ///
                         2 "Foreign" )  ///
                   pos(6) cols(2))      ///
            name(legendtitle3, replace)
//endex
//graph legendtitle3

/*txt
{pstd}If we have the legend in one column, we can add a bit of space after 
the title in the following way:{p_end}
txt*/

//ex
        scatter price0 price1 weight,   ///
            legend(order(- "Legend" " " ///   
                         1 "Domestic"   ///
                         2 "Foreign" )) ///
            name(legendtitle4, replace)
//endex
//graph legendtitle4

/*txt
{center:{bf:Try it yourself}}

{pstd}
The uni.dta used in the previous Do it yourselfs contains two aditional 
variables: drs and ba. These represent the pre-Bologna degree and the post-Bologna
degrees repsepctively. Create a line graph of these two and change the legend 
to make it work. 

{pstd}
//ho_ignore {stata doedit legend_sol.do : Solution}
txt*/
//apcodefile legend_sol.do
//endslide ---------------------------------------------------------------------

//subsection symbol

//slide ------------------------------------------------------------------------
//title  Choose your symbol

/*txt
{pstd}In a scatter graph you can choose the symbol with the {cmd:msymbol()} 
option{p_end}

{pstd}This is documented in {help scatter}{p_end}
txt*/

//ex
        graph drop _all
        sysuse auto, clear
        separate price, by(foreign)
        scatter price0 price1 weight ,  ///
            legend(order(1 "Domestic"   ///
                         2 "Foreign"))  ///
            msymbol(T X)                ///
            name(symbol1, replace)
//endex
//graph symbol1

/*txt
{pstd}Many symbols have a hollow version, which you get by adding an h{p_end}
txt*/

//ex
        scatter price0 price1 weight ,  ///
            legend(order(1 "Domestic"   ///
                         2 "Foreign"))  ///
            msymbol(Th D)               ///
            name(symbol2, replace)
//endex
//graph symbol2
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  Symbol color

/*txt
{pstd}You can change the color of the symbols using the {cmd:mcolor()} option{p_end}

{pstd}This is documenten in {help scatter}{p_end}
txt*/

//ex
        scatter price0 price1 weight ,  ///
            legend(order(1 "Domestic"   ///
                         2 "Foreign"))  ///
            msymbol(O O)                ///
            mcolor(red gs8)             ///
            name(symbol3, replace)
//endex
//graph symbol3
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  Labeling points

/*txt
{pstd}You can also add labels to the points with the {cmd:mlabel()} option{p_end}

{pstd}This is documented in {help scatter}{p_end}
txt*/

//ex
        gen str man = word(make, 1)
        scatter price weight,           ///
            mlabel(man)                 ///
            name(symbol4, replace) 
//endex
//graph symbol4

/*txt
{pstd}You can also fully replace the symbol with the marker label{p_end}
txt*/
//ex
        scatter price weight,           ///
            mlabel(man) mlabpos(0)      ///
            msymbol(i)                  ///
            name(symbol5, replace) 
//endex
//graph symbol5

//endslide ---------------------------------------------------------------------

//subsection line


//slide ------------------------------------------------------------------------
//title  Line pattern
/*txt
{pstd}You can change the pattern using the {cmd:lpattern()} option{p_end}

{pstd}This is documented in {help connect options}{p_end}

{pstd}With {cmd:...} you say that all subsequent graphs have the same pattern{p_end}
txt*/

//ex
        graph drop _all
        use voter, clear
        separate prop, by(candidate) veryshortlabel
        twoway line prop1 prop2 prop3 hhinc,   ///
            xlabel(1/6, valuelabel angle(30))  ///
            ytitle(proportion)                 ///
            lcolor(green gs3 purple)           ///
            lpattern(solid ...)                ///
            name(pattern1, replace)
//endex
//graph pattern1
/*txt
{pstd}Here is another illustration of how {cmd:...} works.{p_end}
txt*/

//ex
        twoway line prop1 prop2 prop3 hhinc,    ///
            xlabel(1/6, valuelabel angle(30))   ///
            ytitle(proportion)                  ///
            lcolor(black ...)                   ///
            lpattern(dash solid ...)            ///
            name(pattern2, replace)
//endex
//graph pattern2
//endslide ---------------------------------------------------------------------


//slide ------------------------------------------------------------------------
//title  Line color

/*txt
{pstd}You can change the collor of a line in a line graph using the 
{cmd:lcolor()} option{p_end}

{pstd}This is documented in {help connect options}{p_end}
txt*/

//ex
        twoway line prop1 prop2 prop3 hhinc,  ///
            xlabel(1/6, valuelabel angle(30)) ///
            ytitle(proportion)                ///
            lcolor(green gs3 purple)          ///
            name(color1, replace)
//endex
//graph color1

//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  Width

/*txt
{pstd}The width of the lines is governed by the {cmd:lwidth()} option.{p_end}

{pstd}This is documented in {help connect options}{p_end}
txt*/

//ex
        twoway line prop1 prop2 prop3 hhinc,  ///
            xlabel(1/6, valuelabel angle(30)) ///
            ytitle(proportion)                ///
            lpattern(solid ...)               ///
            lwidth(vthin medthick vvthick)    ///
            name(width, replace)
//endex
//graph width


//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  Connect styles

/*txt
{pstd}Normally, the sort order in the data determine which points are connected{p_end}

{pstd}Sometimes that is not what we want{p_end}
txt*/

//ex
        graph drop _all
        sort candidat hhinc
        list candidat hhinc prop
        twoway line prop hhinc,          ///
            name(connect1, replace)
//endex
//graph connect1
/*txt
{pstd}Sometimes we only want to connect lines when its x-value has increased{p_end}
txt*/

//ex
        twoway line prop hhinc,          ///
            connect(L)                 ///
            name(connect2, replace)
//endex
//graph connect2
/*txt
{pstd}Normaly the point are connected directly, but you can also first move 
horizontally to the new x-position and than vertically to the new y position, or 
{it:vice versa}.{p_end}
txt*/

//ex
        twoway line prop1 prop1 prop1 hhinc, ///
            connect(J l stepstair)         ///
            name(connect3, replace)
//endex
//graph connect3

/*txt
{pstd}Normally missing values are simply ignored and no break will appear in the line.{p_end}
txt*/

//ex
        replace prop2 = . in 9
        twoway line prop2 hhinc,              ///
            name(connect4, replace)
//endex
//graph connect4

/*txt
{pstd}You can add breaks at missing values using the {cmd:cmissing(n)} option{p_end}
txt*/

//ex
        twoway line prop2 hhinc,              ///
            cmissing(n)                     ///
            name(connect5, replace)
//endex
//graph connect5

/*txt
{pstd}All this is documented in {help connect options}{p_end}
txt*/

/*txt
{center:{bf:Try it yourself}}

{pstd}
Continue work on the graph made in the previous Do it yourself. Add a line 
representing the total number of diploma, and make sure all three lines are 
visible. For 1943 and 1944 there is no data on the number of diplomas. Change the
line to represent that.

{pstd}
//ho_ignore {stata doedit linestyle_sol.do : Solution}
txt*/
//apcodefile linestyle_sol.do
//endslide ---------------------------------------------------------------------


//subsection area

//slide ------------------------------------------------------------------------
//title  the area around the graph

/*txt
{pstd}You can determine whether your plot has a border around it or not 
with the {cmd:plotregion()} option{p_end}

{pstd}This is documented in {help region options}{p_end}
txt*/

//ex
        graph drop _all
        sysuse auto, clear
        scatter price weight,         ///
            plotregion(lstyle(none))  ///
            name(border, replace)
//endex
//graph border

/*txt
{pstd}The default scheme has a blueish background shade that some people like
and others don't{p_end}

{pstd}You can get rid of them using the {cmd:graphregion()} option{p_end}
txt*/

//ex
        scatter price weight,         ///
            scheme(s2color)           ///
            name(shaded, replace) 
        
        scatter price weight,         ///
            scheme(s2color)           ///
            graphregion(color(white)) /// <-- new
            name(noshade, replace)
//endex
//graph shaded
//graph noshade
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  The size of the graph

/*txt
{pstd}You can change the height of the graph using the {cmd:ysize()} option.

{pstd}You can change the width of the graph using the {cmd:xsize()} option.

{pstd}This is documenten in {help region options}{p_end}
txt*/

//ex
        graph drop _all
        sysuse auto, clear
        scatter price weight, ///
           ysize(2) name(size)
//endex
//graph size
/*txt
{pstd}Doing this can sometimes lead to labels and titles that are too small
or too large.{p_end}

{pstd}You can use the {cmd:scale()} option to correct this.{p_end}

{pstd}This is documented in {help scale option}. {p_end}
txt*/


//ex
        scatter price weight,   ///
            ysize(2) scale(1.5) ///
            name(size2)
//endex
//graph size2
/*txt
{pstd}You can also change the relative height of the plotregion instead
of the height of the graph.{p_end}

{pstd}This can make sense if you are plotting two variables with the same
scale against one another, for example own education versus partner's education.{p_end}
txt*/

//ex
        scatter price weight,  ///
            aspect(1) name(size3)
//endex
//graph size3
//endslide ---------------------------------------------------------------------

//subsection schemes

//slide ------------------------------------------------------------------------
//title Schemes

/*txt
{pstd}With schemes you set the overall look of the graph{p_end}
txt*/

//ex
        sysuse auto, clear
        scatter price mpg, scheme(s2color) name(s2color, replace)
        scatter price mpg, scheme(s1mono) name(s1mono, replace)
        scatter price mpg, scheme(s1rcolor) name(s1rcolor, replace)
        scatter price mpg, scheme(economist) name(economist, replace)
//endex
//graph s2color
//graph s1mono
//graph s1rcolor
//graph economist
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title Set scheme

/*txt
{pstd}If you have a favorite scheme, you can use {cmd:set scheme}
       to set it as your default.{p_end}

{pstd}That way you don't have to use the {cmd:scheme()} option each 
       time you create a graph{p_end}
txt*/

//ex
        set scheme s1rcolor
        sysuse auto, clear
        scatter price mpg, name(price5, replace)
        scatter weight mpg, name(weight2, replace)
//endex
//graph price5
//graph weight2
/*txt
{pstd}{cmd:set scheme} only sets the scheme for this session of Stata.{p_end}

{pstd}When you restart Stata you'll return to the default scheme.{p_end}

{pstd}If you want to set the scheme for all futur session, then you add the
       {cmd:permanently} option to {cmd:set scheme}. {p_end}
txt*/
//endslide ---------------------------------------------------------------------



//slide ------------------------------------------------------------------------
//title User scheme

/*txt
{pstd}User's can write their own schemes{p_end}

{pstd}A very useful one, and my default, is the lean1 scheme from Svend Juul.{p_end}

{pstd}To find it type in Stata {stata "search lean"}{p_end}
txt*/
//ex
        set scheme lean1, permanently
        sysuse auto, clear
        scatter price mpg, name(price6, replace)
        scatter weight mpg, name(weight3, replace)
//endex
//graph price6
//graph weight3
//endslide ---------------------------------------------------------------------

//section building a graph

//slide ------------------------------------------------------------------------
//title  Work flow
/*txt
{pstd}A lot of work involves getting the data in the right shape before you 
start graphing{p_end}

{pstd}I work in a .do file{p_end}

{pstd}I may experiment using the command window, but the result immediatly ends 
up in the .do file{p_end}

{pstd}I usually start very simple with the main graph without any options{p_end}

{pstd}I add options one at the time, and correct any mistakes (those are many)
as they occur.{p_end}

{pstd}I consult the help files often{p_end}

{pstd}I don't know the exact names of all the help files. I usually start with 
{help scatter} or {help line}, and click my way through the links.{p_end}
txt*/

//endslide ---------------------------------------------------------------------

//subsection stacking graphs

//slide ------------------------------------------------------------------------
//title  Stacking graphs

/*txt
{pstd}A very powerful trick is that you can stack {cmd:twoway} graphs on top
of one another.{p_end}
txt*/

//ex
        sysuse auto, clear
        graph drop _all
        reg price mpg
        predict pricehat
        predict se , stdp
        gen lb = pricehat - invttail(e(df_r), .025)*se
        gen ub = pricehat + invttail(e(df_r), .025)*se
        twoway                         /// 
          rarea lb ub mpg,             ///
            sort astyle(ci)         || ///
          line pricehat mpg,           ///
            sort lpattern(solid)    || ///
          scatter price mpg,           ///
            msymbol(oh)                ///
            legend(off)                ///
            ytitle(price)              ///
            name(stack1, replace)
//endex
//graph stack1

/*txt
{pstd}The order in which you mention graphs will be the order in which they are
drawn.{p_end}

{pstd}So if you draw an area graph, then it will cover anything drawn before it{p_end}
txt*/

//ex
        twoway                         /// 
          scatter price mpg,           ///
            msymbol(oh)             || ///
          rarea lb ub mpg,             ///
            sort astyle(ci)         || ///
          line pricehat mpg,           ///
            sort lpattern(solid)       ///
            legend(off)                ///
            ytitle(price)              ///
            name(stack2, replace)
//endex
//graph stack2

/*txt
{pstd}You can overcome that by changing the opacity of the object
txt*/

//ex
        twoway                         /// 
          scatter price mpg,           ///
            msymbol(oh)             || ///
          rarea lb ub mpg,             ///
            sort astyle(ci)            ///
            acolor(%50)             || ///
          line pricehat mpg,           ///
            sort lpattern(solid)       ///
            legend(off)                ///
            ytitle(price)              ///
            name(stack3, replace)
//endex
//graph stack3

//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  Hiding parts of a graph

/*txt
{pstd}We looked previously at the joint effect of total experience and tenure.{p_end} 

{pstd}But not all combinations of these two variables are possible:{p_end}

{pstd}If you have been two years at a company, you cannot have less than two years
total experience.{p_end}
txt*/

//ex
        graph drop _all
        sysuse nlsw88, clear
        scatter ttl_exp tenure, name(impossible, replace)
//endex
//graph impossible

/*txt
{pstd}So there is a triangle in the plot below that makes no sense.{p_end}
txt*/

//ex
        reg wage c.ttl_exp##c.ttl_exp##c.tenure##c.tenure
        drop _all
        set obs 30
        gen ttl_exp = _n - 1
        gen tenure  = _n - 1 if _n < 27
        fillin ttl_exp tenure
        drop if tenure == .
        predict wagehat
        
        twoway contour wagehat ttl_exp tenure , ///
            ccuts(2(1)16)                       ///
            name(triangle1, replace)
//endex
//graph triangle1

/*txt
{pstd}We can draw such a triangle as follows{p_end}
txt*/

//ex
        twoway function y=x, range(0 25) recast(area) ///
        name(triangle2, replace)
//endex
//graph triangle2

/*txt
{pstd}We can cover the non-sensical part as so:{p_end}
txt*/
//ex
        twoway contour wagehat ttl_exp tenure ,   ///
            ccuts(2(1)16) ||                      ///
               function y=x,                      ///
            range(0 25) recast(area) color(white) ///
            xtitle(tenure)                        ///
            ytitle(total experience)              ///
            ztitle(predicted wage)                ///
            name(triangle3, replace) 
//endex
//graph triangle3

/*txt
{pstd}The lowest category in the legend still looks too long, which we can 
fix with the {cmd:if} condition{p_end}
txt*/
//ex
        twoway contour wagehat ttl_exp tenure if wagehat > 1, ///
            ccuts(2(1)16) ||                                  ///
               function y=x,                                  ///
            range(0 25) recast(area) color(white)             ///
            xtitle(tenure)                                    ///
            ytitle(total experience)                          ///
            ztitle(predicted wage)                            ///
            name(triangle4, replace) 
//endex
//graph triangle4

//endslide ---------------------------------------------------------------------


//slide ------------------------------------------------------------------------
//title  Stacking area graphs and using the other y-axis
/*txt
{pstd}We can use stacked area plots to show a change in the composition of a 
population over time.{p_end}
txt*/
//ex
        use ZA4578_v1-0-0.dta, clear
        graph drop _all
        gen year = V2
        gen pol = ceil(V24/2) if !inlist(V24,0,97, 98, 99)
        bys year pol : gen n = _N if _n == 1 & pol != .
        bys year : egen N = total(n)
        bys year (pol) : gen cum = sum(n)
        replace cum = cum / N
        twoway area cum year if pol == 5 || ///
               area cum year if pol == 4 || ///
               area cum year if pol == 3 || ///
               area cum year if pol == 2 || ///
               area cum year if pol == 1 ,  ///
            name(comp1, replace)
//endex
//graph comp1
/*txt
{pstd}We want to change the legend, and the margins around the graph is also 
something we may want to remove.{p_end}
txt*/
//ex
        twoway area cum year if pol == 5 ||   ///
               area cum year if pol == 4 ||   ///
               area cum year if pol == 3 ||   ///
               area cum year if pol == 2 ||   ///
               area cum year if pol == 1 ,    ///
            plotregion(margin(zero))          ///
            legend(order(1 "right"            ///
                         2 "somewhat" "right" ///
                         3 "middle"           ///
                         4 "somewhat" "left"  ///
                         5 "left"))           ///
            name(comp2, replace)
//endex
//graph comp2
/*txt
{pstd}We can also use a second y-axis to label each area{p_end}
txt*/
//ex
        sum cum if pol == 5 & year == 2012, meanonly
        local pos = r(mean)
        sum cum if pol == 4 & year == 2012, meanonly
        local pos = r(mean) + (`pos' - r(mean))/2
        local yscale `"`pos' "right""'

        sum cum if pol == 4 & year == 2012, meanonly
        local pos = r(mean)
        sum cum if pol == 3 & year == 2012, meanonly
        local pos = r(mean) + (`pos' - r(mean))/2
        local yscale `"`yscale' `pos' `""somewhat" "right""'"'

        sum cum if pol == 3 & year == 2012, meanonly
        local pos = r(mean)
        sum cum if pol == 2 & year == 2012, meanonly
        local pos = r(mean) + (`pos' - r(mean))/2
        local yscale `"`yscale' `pos' "middle" "'

        sum cum if pol == 2 & year == 2012, meanonly
        local pos = r(mean)
        sum cum if pol == 1 & year == 2012, meanonly
        local pos = r(mean) + (`pos' - r(mean))/2
        local yscale `"`yscale' `pos' `""somewhat" "left""'"'

        local pos = 0 + (0+r(mean))/2
        local yscale `"`yscale' `pos' "left""'

        twoway area cum year if pol == 5 ||          ///
               area cum year if pol == 4 ||          ///
               area cum year if pol == 3 ||          ///
               area cum year if pol == 2 ||          ///
               area cum year if pol == 1,            ///
            yscale(range(0 1)) ||                    ///
               scatteri .5 2010, msymbol(i)          ///
            yaxis(2) yscale(range(0 1) axis(2))      ///
            ylab(`yscale', axis(2)) legend(off)      ///
            plotregion(margin(zero))                 ///
            ytitle("cumulative proportion", axis(1)) ///
            ytitle("", axis(2))                      ///
            xtitle(year)                             ///
            name(comp3, replace)
//endex
//graph comp3
/*txt
{pstd}Notice that the labels left and middle are misalligned.{p_end}

{pstd}This is a bug in Stata, and we can fix it as follows:{p_end}
txt*/
//ex
        sum cum if pol == 5 & year == 2012, meanonly
        local pos = r(mean)
        sum cum if pol == 4 & year == 2012, meanonly
        local pos = r(mean) + (`pos' - r(mean))/2
        local yscale `"`pos' "right""'

        sum cum if pol == 4 & year == 2012, meanonly
        local pos = r(mean)
        sum cum if pol == 3 & year == 2012, meanonly
        local pos = r(mean) + (`pos' - r(mean))/2
        local yscale `"`yscale' `pos' `""somewhat" "right""'"'

        sum cum if pol == 3 & year == 2012, meanonly
        local pos = r(mean)
        sum cum if pol == 2 & year == 2012, meanonly
        local pos = r(mean) + (`pos' - r(mean))/2
        local yscale `"`yscale' `pos' `"" " "middle" " ""'"'

        sum cum if pol == 2 & year == 2012, meanonly
        local pos = r(mean)
        sum cum if pol == 1 & year == 2012, meanonly
        local pos = r(mean) + (`pos' - r(mean))/2
        local yscale `"`yscale' `pos' `""somewhat" "left""'"'

        local pos = 0 + (0+r(mean))/2
        local yscale `"`yscale' `pos' `"" " "left" " ""'"'

        twoway area cum year if pol == 5 ||          ///
               area cum year if pol == 4 ||          ///
               area cum year if pol == 3 ||          ///
               area cum year if pol == 2 ||          ///
               area cum year if pol == 1,            ///
            yscale(range(0 1)) ||                    ///
               scatteri .5 2010, msymbol(i)          ///
            yaxis(2) yscale(range(0 1) axis(2))      ///
            ylab(`yscale', axis(2)) legend(off)      ///
            plotregion(margin(zero))                 ///
            ytitle("cumulative proportion", axis(1)) ///
            ytitle("", axis(2))                      ///
            xtitle(year)                             ///
            name(comp4, replace)
//endex
//graph comp4
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  Labeling points

/*txt
{pstd}We can improve our arrow plot by adding labels telling use at which year
each point occured{p_end}
txt*/

//ex
        use ecassess, clear
        gen sort = _n
        tsset sort
        twoway pcarrow L.own L.brd own brd,       ///
            ytitle("assessment of"                ///
                   "own economic position")       ///
            xtitle("assessment of"                ///
                   "Germany's economic position") ///
            name(pcarrow2, replace)           ||  ///
        scatter own brd, msymbol(i) mlabel(year) legend(off)
//endex
//graph pcarrow2

/*txt
{pstd}
The label overlap. We can tell Stata where to put the label relative to the 
point using the {cmd:mlabvpos()} option.

{pstd}
This requires that we create a new variable that tells where the label should be.

{pstd}
This new variable contains a {help clockposstyle: clock position}, so 12 is
above the point, 3 is to the right, etc.
txt*/

//ex
        gen byte labpos =  6 if year == 1982
        replace  labpos =  6 if year == 1984
        replace  labpos = 11 if year == 1986
        replace  labpos =  6 if year == 1990
        replace  labpos = 12 if year == 1991
        replace  labpos = 12 if year == 1992
        replace  labpos =  3 if year == 1994
        replace  labpos =  2 if year == 1996
        replace  labpos =  3 if year == 1998
        replace  labpos =  9 if year == 2000
        replace  labpos = 11 if year == 2002
        replace  labpos =  6 if year == 2004
        replace  labpos =  6 if year == 2006
        replace  labpos =  9 if year == 2008
        replace  labpos =  3 if year == 2010
        replace  labpos =  6 if year == 2012

        twoway pcarrow L.own L.brd own brd,       ///
            ytitle("assessment of"                ///
                   "own economic position")       ///
            xtitle("assessment of"                ///
                   "Germany's economic position") ///
            name(pcarrow3, replace)           ||  ///
        scatter own brd, msymbol(i) mlabel(year)  ///
        legend(off) mlabvpos(labpos)
//endex
//graph pcarrow3

/*txt
{center:{bf:Try it yourself}}

{pstd}
Below we use {help predictnl} to create predicted wage for different values of 
ttl_exp, while keeping race, grade, and union constant, and the 95% confidence
interval around it. Use these variables to create a graph
txt*/


//ex
sysuse nlsw88, clear
poisson wage c.ttl_exp##c.ttl_exp i.race grade i.union, vce(robust) irr
replace race = 1 if race < .
replace grade = 12 if grade < .
replace union = 0 if union < .
 
predictnl wagehat = exp(xb()), ci(lb ub)
//endex

/*txt
{pstd}
//ho_ignore {stata doedit stack_sol.do : Solution}
txt*/
//apcodefile stack_sol.do
//endslide ---------------------------------------------------------------------



//subsection immediate commands
//slide ------------------------------------------------------------------------
//title  Immediate commands

/*txt
{pstd}With immediate commands you "type in the data" as part of the command.{p_end}

{pstd}Say we have developed a scale for educational levels and want to display that.{p_end}
txt*/

//ex
        graph drop _all
        twoway scatteri 1 7.5 (6) "primary"          ///
                        1 8.75 (6) "Haupt"           ///
                        1 12.25 (7) "Real"           ///
                        1 12.75 (5) "Abi"            ///
                        1 11 (12) "Haupt + voc"      ///
                        1 12.5 (12) "Real + voc"     ///
                        1 14.5 (12) "Abi + voc"      ///
                        1 16 (6) "Fachhochschule"    ///
                        1 17.5 (12) "Uni",           ///
            name(edscale1, replace) 
//endex
//graph edscale1
/*txt
{pstd}We can add a horizontal line on which the educational levels are located.{p_end}
txt*/

//ex
        twoway function y = 1,                       ///
            range(7.5 17.5)                          ///
            lpattern(solid) lcolor(gs8)           || ///
               scatteri 1 7.5 (6) "primary"          ///
                        1 8.75 (6) "Haupt"           ///
                        1 12.25 (7) "Real"           ///
                        1 12.75 (5) "Abi"            ///
                        1 11 (12) "Haupt + voc"      ///
                        1 12.5 (12) "Real + voc"     ///
                        1 14.5 (12) "Abi + voc"      ///
                        1 16 (6) "Fachhochschule"    ///
                        1 17.5 (12) "Uni",           ///
            name(edscale2, replace) 
//endex
//graph edscale2
/*txt
{pstd}The y-axis and the legend contain no information, so those need to be 
removed.{p_end}

{pstd}It is more a diagram then a graph, so an outline around the graph makes 
less sense.{p_end}
txt*/

//ex
        twoway function y = 1,                       ///
            range(7.5 17.5)                          ///
            lpattern(solid) lcolor(gs8)           || ///
               scatteri 1 7.5 (6) "primary"          ///
                        1 8.75 (6) "Haupt"           ///
                        1 12.25 (7) "Real"           ///
                        1 12.75 (5) "Abi"            ///
                        1 11 (12) "Haupt + voc"      ///
                        1 12.5 (12) "Real + voc"     ///
                        1 14.5 (12) "Abi + voc"      ///
                        1 16 (6) "Fachhochschule"    ///
                        1 17.5 (12) "Uni",           ///
            name(edscale3, replace)                  ///
            yscale(off) plotregion(lstyle(none))     ///
            xtitle("pseudo-years of education")      ///
            xscale(range(7 18)) legend(off)
//endex
//graph edscale3
/*txt
{pstd}We can make the graph flatter with the {cmd:ysize()} option{p_end}
txt*/

//ex
        twoway function y = 1,                       ///
            range(7.5 17.5)                          ///
            lpattern(solid) lcolor(gs8)           || ///
               scatteri 1 7.5 (6) "primary"          ///
                        1 8.75 (6) "Haupt"           ///
                        1 12.25 (7) "Real"           ///
                        1 12.75 (5) "Abi"            ///
                        1 11 (12) "Haupt + voc"      ///
                        1 12.5 (12) "Real + voc"     ///
                        1 14.5 (12) "Abi + voc"      ///
                        1 16 (6) "Fachhochschule"    ///
                        1 17.5 (12) "Uni",           ///
            name(edscale4, replace)                  ///
            yscale(off) plotregion(lstyle(none))     ///
            xtitle("pseudo-years of education")      ///
            xscale(range(7 18)) legend(off)          ///
            ysize(2)
//endex
//graph edscale4
/*txt
{pstd}But now the symbols and fonts are too small, which we can fix with the 
{cmd:scale option}{p_end}
txt*/

//ex
        twoway function y = 1,                       ///
            range(7.5 17.5)                          ///
            lpattern(solid) lcolor(gs8)           || ///
               scatteri 1 7.5 (6) "primary"          ///
                        1 8.75 (6) "Haupt"           ///
                        1 12.25 (7) "Real"           ///
                        1 12.75 (5) "Abi"            ///
                        1 11 (12) "Haupt + voc"      ///
                        1 12.5 (12) "Real + voc"     ///
                        1 14.5 (12) "Abi + voc"      ///
                        1 16 (6) "Fachhochschule"    ///
                        1 17.5 (12) "Uni",           ///
            name(edscale5, replace)                  ///
            yscale(off) plotregion(lstyle(none))     ///
            xtitle("pseudo-years of education")      ///
            xscale(range(7 18)) legend(off)          ///
            ysize(2) scale(2.5)
//endex
//graph edscale5
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  Immediate commands with arrows

/*txt
{pstd}Say we want to create a diagram showing that the effect of X on Y is 
mediated by Z.

{pstd}We can start with putting X Y and Z on a graph{p_end}
txt*/

//ex
        graph drop _all
        
        twoway scatteri 0 0   (0)  "X"  ///
                        0 1   (0)  "Y"  ///
                        1 0.5 (12) "Z", ///
            name(indir1, replace)  
//endex
//graph indir1
/*txt
{pstd}We can remove the markers and make the labels larger{p_end}
txt*/

//ex
        twoway scatteri 0 0   (0)  "X"  ///
                        0 1   (0)  "Y"  ///
                        1 0.5 (12) "Z", ///
            msymbol(i) mlabsize(large)  ///
            name(indir2, replace)  
//endex
//graph indir2
/*txt
{pstd}We don't need the axes and the plot outline{p_end}
txt*/

//ex
        twoway scatteri 0 0   (0)  "X"     ///
                        0 1   (0)  "Y"     ///
                        1 0.5 (12) "Z",    ///
            msymbol(i) mlabsize(large)     ///
            yscale(range(-.2 1.2) off)     ///
            ylab(0 1,nolabels noticks)     ///
            xscale(range(-.2 1.2) off)     ///
            ytitle("") xtitle("")          ///
            plotregion(lstyle(none))       ///
            name(indir3, replace)  
//endex
//graph indir3
/*txt
{pstd}We can draw the first arrow{p_end}
txt*/

//ex
        twoway scatteri 0 0   (0)  "X"     ///
                        0 1   (0)  "Y"     ///
                        1 0.5 (12) "Z",    ///
            msymbol(i) mlabsize(large)     ///
            msymbol(i) mlabsize(large)     ///
            yscale(range(-.2 1.2) off)     ///
            ylab(0 1,nolabels noticks)     ///
            xscale(range(-.2 1.2) off)     ///
            ytitle("") xtitle("")          ///
            plotregion(lstyle(none))       ///
            name(indir4, replace)       || ///
               pcarrowi 0 .1 0 .9
//endex
//graph indir4
/*txt
{pstd}Make sure it looks right{p_end}
txt*/
//ex
        twoway scatteri 0 0   (0)  "X"              ///
                        0 1   (0)  "Y"              ///
                        1 0.5 (12) "Z",             ///
            msymbol(i) mlabsize(large)              ///
            msymbol(i) mlabsize(large)              ///
            yscale(range(-.2 1.2) off)              /// 
            ylab(0 1,nolabels noticks)              ///
            xscale(range(-.2 1.2) off)              ///
            ytitle("") xtitle("")                   ///
            plotregion(lstyle(none))                ///
            name(indir5, replace)                || ///
               pcarrowi 0 .1 0 .9,                  /// 
            legend(off)                             ///
            msize(*2) lwidth(*1.8) mlwidth(*1.8)    
//endex
//graph indir5
/*txt
{pstd}Than add the remaining arrows{p_end}
txt*/

//ex
        twoway scatteri 0 0   (0)  "X"              ///
                        0 1   (0)  "Y"              ///
                        1 0.5 (12) "Z",             ///
            msymbol(i) mlabsize(large)              ///
            msymbol(i) mlabsize(large)              ///
            yscale(range(-.2 1.2) off)              /// 
            ylab(0 1,nolabels noticks)              ///
            xscale(range(-.2 1.2) off)              ///
            ytitle("") xtitle("")                   ///
            plotregion(lstyle(none))                ///
            name(indir6, replace)                || ///
               pcarrowi 0 .1 0 .9,                  /// 
            legend(off)                             ///
            msize(*2) lwidth(*1.8) mlwidth(*1.8) || ///
               pcarrowi .95 .525 0.05 .95,          /// 
            legend(off)                             ///
            msize(*2) lwidth(*1.8) mlwidth(*1.8) || ///
               pcarrowi 0.05 .05 .95 .475,          /// 
            legend(off)                             ///
            msize(*2) lwidth(*1.8) mlwidth(*1.8) 
//endex
//graph indir6
//endslide ---------------------------------------------------------------------

//subsection data
//slide ------------------------------------------------------------------------
//title  Preparing data for a graph

/*txt
{pstd}Preparing data especially for graqphs is a powerful strategy for creating graphs{p_end}
txt*/

//ex
        sysuse nlsw88, clear
        graph drop _all
        bys industry : egen mwage = mean(wage)
        twoway scatter industry mwage, ///
           ylab(1/12, valuelabel)      ///
           name(mwage1, replace)
//endex
//graph mwage1
/*txt
{pstd}The graph would be clearer if the industries were sorted by mean wage{p_end}

{pstd}We can do so witht he {cmd:axis} user written {cmd:egen} function, which is
part of {egenmore}{p_end}

{pstd}You can get {cmd:egenmore} by typing {cmd:ssc install egenmore}{p_end}
txt*/

//ex
        egen Industry = axis(mwage industry) , label(industry)
        twoway scatter Industry mwage, ///
            ylab(1/12, valuelabel)     ///
            ytitle("")                 ///
            xtitle("mean wage")        ///
            name(mwage2, replace)
        graph save gr1, replace
//endex
//graph mwage2
/*txt
{pstd} Each observation in the data appears in this graph, but we need only one
observation per industry. By plotting only one point per industry we can safe some memory{p_end}
txt*/

//ex
        bys industry : gen byte mark = _n == 1
        
        twoway scatter Industry mwage if mark, ///
            ylab(1/12, valuelabel)             ///
            ytitle("")                         ///
            xtitle("mean wage")                ///
            name(mwage3, replace)
        graph save gr2, replace
        
        dir *.gph
//endex
//graph mwage3

//endslide ---------------------------------------------------------------------

//subsection nontwoway

//slide ------------------------------------------------------------------------
//title  Non-twoway graphs

/*txt
{pstd}Not all graphs in Stata are {cmd:twoway}, for example {help graph bar}, 
{help histogram}, and {help graph pie}{p_end}

{pstd}They are usually less flexible and it is harder to stack graphs, though 
some have the {cmd:addplot()} option.{p_end}
txt*/
//endslide ---------------------------------------------------------------------

//section Graphs side by side
//subsection combine
//slide ------------------------------------------------------------------------
//title  Combining graphs

/*txt
{pstd}We can use {help graph combine} to put two or more graphs next to one 
another{p_end}
txt*/
//ex
        sysuse uslifeexp, clear
        line le_male   year, name(male, replace)
        line le_female year, name(female, replace)
        graph combine male female, name(comb1, replace)
//endex
//graph comb1
/*txt
{pstd}Notice that the y-axes of the two graphs are not alligned{p_end}
txt*/
//ex
        graph combine male female, ///
            name(comb2, replace)   ///
            ycommon 
//endex
//graph comb2
/*txt
{pstd}We can also put the graphs underneath one another.{p_end}
txt*/
//ex
        graph combine male female, ///
            name(comb3, replace)   ///
            ycommon cols(1)
//endex
//graph comb3
/*txt
{pstd}We can add titles{p_end}
txt*/
//ex
        line le_male   year, ///
            title(men) name(male, replace)
        line le_female year, ///
            title(women) name(female, replace)
        graph combine male female, ///
            name(comb4, replace) ///
            title(Life exepectancy in the USA) ///
            ycommon
//endex
//graph comb4
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  Legends in a combined graph

/*txt
{pstd}If we are legends part of the graphs that are combined, then these will 
be repeated. Which will give the same information twice (or more){p_end}
txt*/

//ex
        graph drop _all
        use ecassess, clear
        
        twoway line brd_h own_h year,          ///
            legend(order(1 "Germany" 2 "Own")) ///
            title(high income)                 ///
            name(high, replace)
        
        twoway line brd_l own_l year,          ///
            legend(order(1 "Germany" 2 "Own")) ///
            title(low income)                  ///
            name(low, replace)
        
        graph combine high low,                     ///
            title(Assessment of economic situation) ///
            ycommon name(combine, replace)
//endex
//graph high
//graph low
//graph combine
/*txt
{pstd}You can use the user written command {cmd:grc1leg}, to use just one of 
these legends after combining graphs.{p_end}
txt*/

//ex
        grc1leg high low,                           ///
            title(Assessment of economic situation) ///
            ycommon name(grc1leg, replace)
//endex
//graph grc1leg
//endslide ---------------------------------------------------------------------

//anc --------------------------------------------------------------------------
//title  Combine with one legend from first principle

/*txt
{pstd}A graph file is a set of instructions that tells Stata what to draw where{p_end}

{pstd}It is a text-file and we can look at it{p_end}

{pstd}We can use this to change our graphs{p_end}

{pstd}Normally you would never do this, but the trick below is sometimes useful
when {cmd:grc1leg} does not exactly do what you want{p_end}

{pstd}You start by combining the two graphs, but without any legends{p_end}
txt*/

//ex
        use ecassess, clear
        twoway line brd_h own_h year,          ///
            legend(off)                        ///
            title(high income)                 ///
            name(high2, replace)
        
        twoway line brd_l own_l year,          ///
            legend(off)                        ///
            title(low income)                  ///
            name(low2, replace)
        
        graph combine high2 low2, cols(1) name(two, replace)
//endex
//graph high2
//graph low2
//graph two
/*txt
{pstd}We then want to create a new graph that is only a legend.{p_end}

{pstd}We start with creating a regular graph with legend, but turn off as much
as we can using {cmd:yscale(off)} and {cmd:xscale(off)}
txt*/

//ex
        twoway line brd_h own_h year,                  ///
            legend(order(1 "Germany" 2 "Own")          ///
            cols(1) pos(3) )                           ///
            yscale(off) xscale(off)                    ///
            name(leg, replace)
//endex
//graph leg
/*txt
{pstd}We then suppress the graph, so that the legend is all that is left{p_end}
txt*/

//ex
        _gm_edit .leg.plotregion1.draw_view.set_false
        graph display
//endex

/*txt
{pstd}The command below prevents the legend graph to take just as much room as
the main graph.
txt*/

//ex
        . _gm_edit .leg.xstretch.set fixed
        . graph display
//endex

/*txt
{pstd}All we need to do is combine the legend graph with combined graph{p_end}
txt*/

//ex
        graph combine two leg , cols(2) name(mancomb1)
//endex
//graph mancomb1

/*txt
{pstd}We add the legend to the side, but we can also add it underneath.{p_end}
txt*/

//ex
        twoway line brd_h own_h year,          ///
            legend(off)                        ///
            title(high income)                 ///
            name(high3, replace)
        
        twoway line brd_l own_l year,          ///
            legend(off)                        ///
            title(low income)                  ///
            name(low3, replace)
        
        graph combine high3 low3, cols(2) name(two3, replace)

        twoway line brd_h own_h year,                  ///
            legend(order(1 "Germany" 2 "Own")          ///
            cols(2) pos(6) )                           ///
            yscale(off) xscale(off)                    ///
            name(leg3, replace)

        _gm_edit .leg.plotregion1.draw_view.set_false
        graph display

        . _gm_edit .leg.ystretch.set fixed
        . graph display

        graph combine two leg , cols(1) name(mancomb2, replace)
//endex
//graph high3
//graph low3
//graph two3
//graph mancomb2

//endanc -----------------------------------------------------------------------


//subsection by

//slide ------------------------------------------------------------------------
//title  By 

/*txt
{pstd}We can also use the {help by option} to put multiple graphs next to one 
another.{p_end}
txt*/

//ex
        graph drop _all
        sysuse auto, clear
        scatter price weight,  /// 
            by(foreign)        ///
            name(by1, replace) 
//endex
//graph by1

/*txt
{pstd}Notice that there is less double information in this graph, e.g. the axis
titles are not repeated{p_end}

{pstd}We can move the graphs closer together, so there is more room for the 
actual graphs, by using the {cmd:compact} sub-option.
txt*/

//ex
        scatter price weight,     ///
            by(foreign, compact)  ///
            name(by2, replace)
//endex
//graph by2

/*txt
{pstd}Adding titles is a bit tricky{p_end}
txt*/

//ex
        scatter price weight,                          ///
            by(foreign)                                ///
            title(relationship between price and wage) ///
            name(by3,replace)
//endex
//graph by3

/*txt
{pstd}The {cmd:title()} options must actually be a sub-option of the {cmd:by()}
option.{p_end}
txt*/

//ex
        scatter price weight,                              ///
            by(foreign,                                    ///
               title(relationship between price and wage)) ///
            name(by4,replace)
//endex
//graph by4

/*txt
{pstd}Within the {cmd:by()} option we can also remove the note.{p_end}
txt*/

//ex
        scatter price weight,                              ///
            by(foreign,                                    ///
               title(relationship between price and wage)  ///
               note("") )                                  ///
            name(by5,replace)
//endex
//graph by5

/*txt
{pstd}We can move the sub-titles inside the graph{p_end}
txt*/

//ex
        scatter price weight,                              ///
            by(foreign,                                    ///
               title(relationship between price and wage)  ///
               note("") )                                  ///
            subtitle(, ring(0) pos(11) nobexpand lstyle(solid))           ///
            name(by6,replace)
//endex
//graph by6

/*txt
{pstd}The sub-titles come from the value labels, so it is good to have those{p_end}

{pstd}With the {cmd:by()} option you automatically get only one legend, so that 
is good{p_end}
txt*/

//ex
        label define rep78 1 "Poor"    ///
                           2 "Fair"    ///
                           3 "Average" ///
                           4 "Good"    ///
                           5 "Excellent"
        label value rep78 rep78 
        separate price, by(foreign)
        scatter price? weight, ///
           by(rep78, note("")) ///
           name(by7)              
//endex
//graph by7

/*txt
{pstd}Though the content of the legend could be prettier. Fortunately, changing
the legend works just as before{p_end}
txt*/

//ex
        scatter price? weight,        ///
           by(rep78, note(""))        ///
           legend(order(1 "Domestic"  ///
                        2 "Foreign")) ///
           name(by8)              
//endex
//graph by8

/*txt
{pstd}However, changing the position of the legend does not seem to work{p_end}
txt*/

//ex
        scatter price? weight,        ///
           by(rep78, note(""))        ///
           legend(order(1 "Domestic"  ///
                        2 "Foreign")  ///
                  pos(3) ) ///
           name(by9)              
//endex
//graph by9

/*txt
{pstd}For that you need use a sub-option within the {cmd:by()} options.{p_end}
txt*/

//ex
        scatter price? weight,        ///
           by(rep78, note("")         ///
              legend(pos(3)) )        ///
           legend(order(1 "Domestic"  ///
                        2 "Foreign")) ///
           name(by10)              
//endex
//graph by10

/*txt
{pstd}There is some empty space at the 6th plot position, can't we use that 
for the legend?{p_end}
txt*/

//ex
        scatter price? weight,        ///
           by(rep78, note("")         ///
              legend(at(6) pos(0)) )  ///
           legend(order(1 "Domestic"  ///
                        2 "Foreign")) ///
           name(by11)              
//endex
//graph by11

//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  Using by() as an alternative to graph combine

/*txt
{pstd}We can use the {cmd:by()} option as an alternative to {cmd:graph combine}{p_end}

{pstd}To repeat the example from before{p_end}
txt*/

//ex
        graph drop _all
        sysuse uslifeexp, clear
        line le_male   year, name(male, replace)
        line le_female year, name(female, replace)
        graph combine male female, name(bycombine1, replace)
//endex
//graph bycombine1
/*txt
{pstd}We need to {help reshape} the data to use the {cmd:by()} option.
txt*/

//ex
        sysuse uslifeexp, clear
        keep year le_male le_female
        rename le_male   le0
        rename le_female le1
        reshape long le, i(year) j(female)
        label define female 0 "male" 1 "female"
        label variable le "life expectancy"
        label value female female
        line le year, by(female, note("")) name(bycombine2, replace) 
//endex
//graph bycombine2


/*txt
{center:{bf:Try it yourself}}

{pstd}
The economic assessment example can also be done with he {cmd:by} option

{pstd}
Use ecassess.dta to set the two graphs side by side using the {cmd:by} option.
{pstd}
//ho_ignore {stata doedit by_sol.do : Solution}
txt*/
//apcodefile by_sol.do
/*txt
{pstd}
txt*/

//endslide ---------------------------------------------------------------------


//section Graphs in the background

//subsection histograms and bar graphs

//slide ------------------------------------------------------------------------
//title Highlighting sub-populations in a histogram

/*txt
{pstd}We can compare distributions using {cmd:histogram} with the {cmd:by()} 
option.{p_end}
txt*/

//ex 
sysuse nlsw88, clear
twoway histogram wage,     ///
    width(1) freq          ///
    by(collgrad, note("")) ///
    name(hist1, replace)
//endex
//graph hist1

/*txt
{pstd}We can also highlight the part of the histogram that are college 
graduates{p_end}
txt*/

//ex
twoway histogram wage,                       ///
    width(1) freq                            ///
    bcolor(gs14)  blw(*.4) blcolor(black) || /// 
histogram wage if collgrad,                  ///
    width(1) freq legend(off)                ///
    bcolor(gs6) blw(*.4) blcolor(black)      ///
    title(distribution of hourly wage)       ///
    subtitle(college graduates highlighted)  ///
    name(hist2, replace) 
//endex
//graph hist2
//endslide ---------------------------------------------------------------------


//slide ------------------------------------------------------------------------
//title Highlighting bars
//label highlighting bars

/*txt
{pstd}We can {cmd:graph hbar} to display the mean wage by industry.{p_end}
txt*/

//ex
sysuse nlsw88, clear
graph hbar (mean) wage,                       ///
    over(industry, descending sort(1))        ///
    name(bar4, replace)        
//endex
//graph bar4
/*txt

{pstd}Sometimes we want to highlight one bar.{p_end}

{pstd}This is particularly common for presentations.{p_end}
txt*/

//ex
collapse (mean) wage, by(industry)
separate wage, by(industry == 12)
graph hbar (asis) wage0 wage1,                   ///
    over(industry, descending sort(wage)) nofill ///
    bar(1, bfcolor(none)) legend(off)            ///
    ytitle(mean wage)                            ///
    name(bar5, replace)
//endex
//graph bar5
//endslide ---------------------------------------------------------------------

//subsection scatterplots

//slide ------------------------------------------------------------------------
//title Highlighting sub-populations in a scatter plot
//label highlighting in a scatter plot

/*txt
{pstd}We may want to highlight a certain sub-polation in a scatter plot{p_end}

{pstd}We start with a simple scatter plot{p_end}
txt*/

//ex
sysuse nlsw88, clear
graph drop _all
scatter wage grade,         ///
    name(scatter1, replace)
//endex
//graph scatter1

/*txt
{pstd}Grade is discrete, but we can show the individual values by adding the 
jitter() option.{p_end}
txt*/

//ex
scatter wage grade, jitter(2) ///
    name(scatter2, replace)
//endex
//graph scatter2

/*txt
{pstd}The jitter() option adds random noise in both the x and y direction, but 
we only need a jitter in the x-direction{p_end}
txt*/

//ex
gen grade2 = grade + .5*runiform()
scatter wage grade2,           ///
    name(scatter3, replace)
//endex
//graph scatter3

/*txt
{pstd}It would be nice if we could copy the variable label from grade{p_end}
txt*/

//ex
label var grade2 "`: var label grade'"
scatter wage grade2,            ///
    name(scatter4, replace)
//endex
//graph scatter4

/*txt
{pstd}
Alternatively, you can make the symbols "see through", so they are grey when one
symbol is plotted, but become darker if multiple symbols are plotted on top of
one another.
txt*/

//ex
scatter wage grade, mcolor(%25)  ///
   name(scatter5, replace)
//endex
//graph scatter5

/*txt
{pstd}It makes more sense to display wage on a log scal{p_end}
txt*/

//ex
scatter wage grade2, yscale(log) ///
    name(scatter6, replace)
//endex
//graph scatter6

/*txt
{pstd}But we need to adjust the axis labels a bit.{p_end}
txt*/

//ex
scatter wage grade2, yscale(log) ///
    ylab(1.25 2.5 5 10 20 40)    ///
    name(scatter7, replace)
//endex
//graph scatter7

/*txt
{pstd}Now we can highlight the blacks{p_end}
txt*/

//ex
scatter wage grade2, yscale(log)       ///
    msymbol(Oh) mcolor(gs10) ||        ///
scatter wage grade2 if race == 2 ,     ///
    msymbol(O) mcolor(gs2)             ///
    yscale(log) legend(off)            ///
    ylab(1.25 2.5 5 10 20 40)          ///                
    name(scatter8, replace)
//endex
//graph scatter8
//endslide ---------------------------------------------------------------------


//slide ------------------------------------------------------------------------
//title Line on top of a scatter plot
//label background scatter

/*txt
{pstd}We can plot a line on top of a scatter plot{p_end}
txt*/

//ex
graph drop _all
sysuse nlsw88, clear

gen grade2 = grade + .5*runiform()
label var grade2 "`: var label grade'"

fp <grade> , scale: poisson wage <grade>
predict wagehat
twoway scatter wage grade2,                         ///
           yscale(log) ylab(1.25 2.5 5 10 20 40) || ///
       line wagehat grade, sort legend(off)         ///
            name(fit1, replace)
//endex
//graph fit1

/*txt
{pstd}The scatter plot is a bit too dominant{p_end}
txt*/

//ex
twoway scatter wage grade2, mcolor(gs10)            ///
           yscale(log) ylab(1.25 2.5 5 10 20 40) || ///
       line wagehat grade, sort legend(off)         ///
            name(fit2, replace)
//endex
//graph fit2

/*txt
{pstd}The line can be made solid{p_end}
txt*/

//ex
twoway scatter wage grade2, mcolor(gs10)            ///
           yscale(log) ylab(1.25 2.5 5 10 20 40) || ///
       line wagehat grade, sort legend(off)         ///
           lpattern(solid)                          ///
           name(fit3, replace)
//endex
//graph fit3

/*txt
{pstd}We can also make the line thicker{p_end}
txt*/

//ex
twoway scatter wage grade2, mcolor(gs10)            ///
           yscale(log) ylab(1.25 2.5 5 10 20 40) || ///
       line wagehat grade, sort legend(off)         ///
           lpattern(solid) lwidth(*3)               ///
           name(fit4, replace)
//endex
//graph fit4
//endslide 

//subsection by

//slide ------------------------------------------------------------------------
//title By graph
//label by graph

/*txt
{pstd}Lets look at the relationship between GDP per capita and child mortality by country{p_end}
txt*/

//ex
use infmort, clear

sort countryname year
line infmort gdppc,                ///
    yscale(log) xscale(log)           ///
    name(byscatter1, replace)               ///
    ylab( 2 5 10 20 50 100 200)       ///
    xlab(1e3 1e4 1e5, format(%9.0gc)) ///
    by(countryname, compact note(""))
//endex
//graph byscatter1

/*txt
{pstd}We can sort the sub graphs by the initial child mortality{p_end}
txt*/

//ex
gen mis = missing(infmort)
bys countryname mis (year) : gen initmort = infmort[1]
bys countryname (initmort) : replace initmort = initmort[1]
replace initmort = -initmort
egen Country = axis(initmort), label(countryname)
sort Country year
line infmort gdppc,                ///
    yscale(log) xscale(log)           ///
    name(byscatter2, replace)               ///
    ylab( 2 5 10 20 50 100 200)       ///
    xlab(1e3 1e4 1e5, format(%9.0gc)) ///
    by(Country, compact note(""))
//endex
//graph byscatter2

/*txt
{pstd}We can display the entire sample as a background graph{p_end}
txt*/

//ex
use infmort, clear

gen mis = missing(infmort, gdppc)
bys countryname mis (year) : gen initmort = infmort[1]
bys countryname (initmort) : replace initmort = initmort[1]
replace initmort = -initmort
egen Country = axis(initmort), label(countryname)

tempfile temp
save `temp'

keep infmort Country gdppc year
reshape wide infmort gdppc, j(Country) i(year)
merge 1:m year using `temp'

forvalues i = 1/17 {
    local backgr `backgr' line infmort`i' gdppc`i', ///
                          lcolor(gs12) lpattern(solid) ||
}

sort Country year
twoway `backgr'                                ///
    line infmort gdppc,                        ///
    lcolor(black) lwidth(*1.5) lpattern(solid) /// 
    yscale(log) xscale(log)                    ///
    ylab( 2 5 10 20 50 100 200)                ///
    xlab(1e3 1e4 1e5, format(%9.0gc))          ///
    by(Country, compact note("") legend(off))  ///
    name(byscatter3, replace)
//endex
//graph byscatter3

/*txt
{pstd}
We can add labels in the graph indicating the starting and ending year of the 
series and axis titles.
txt*/

//ex
forvalues i = 1/17 {
    local backgr `backgr' line infmort`i' gdppc`i', ///
                          lcolor(gs12) lpattern(solid) ||
}

bys Country mis (year) : gen xmark = gdppc   if (_n == 1 | _n == _N)
bys Country mis (year) : gen ymark = infmort if (_n == 1 | _n == _N)
bys Country mis (year) : gen byte labpos = cond(_n==1,12,3)
bys Country mis (year) : replace labpos = 3 if inlist(Country, 1, 2) & _n == 1
bys Country mis (year) : replace labpos = 1 if inlist(Country, 4, 12) & _n == 1
bys Country mis (year) : replace labpos = 6 if Country == 17 & _n==_N

sort Country year
twoway `backgr'                                                    ///
    line infmort gdppc,                                            ///
    lcolor(black) lwidth(*1.5) lpattern(solid)                     /// 
    yscale(log) xscale(log)                                        ///
    ylab( 2 5 10 20 50 100 200)                                    ///
    xlab(1e3 1e4 1e5, format(%9.0gc))                              ///
    by(Country, compact note("") legend(off))                      ///
    name(byscatter4, replace)                                   || ///
    scatter ymark xmark, msymbol(i)                                ///
    mlabel(year) mlabvpos(labpos)                                  ///
    ytitle("infant mortality (per 1,000 live births)", size(*.75)) ///
    xtitle("GDP per capita (PPPs, 2011 US {c S|})", size(*.75))
//endex
//graph byscatter4
//endslide ---------------------------------------------------------------------

//section Graphing model results

//slide ------------------------------------------------------------------------
//title  Factor variable notation

/*txt
{pstd}factor variables will create dummy variables from
a categorical variables{p_end}
txt*/

//ex
        sysuse auto, clear
        reg price i.rep78
        
        tab rep78, gen(d)
        drop d1
        reg price d?
//endex

/*txt
{pstd}By default the reference category is the one with the smallest
value, but you can change that: e.g. {cmd:reg price ib3.rep78}{p_end}

{pstd}You can also use factor variables to create interactions{p_end}

{pstd}The {cmd:##} add the main effects and the interaction(s) to you 
your model{p_end}

{pstd}If one or more of the interacted variables is continuous, then 
you must add {cmd:c.} in front of those, otherwise it will be treated 
as categorical.{p_end}
txt*/

//ex
        reg price i.foreign##c.weight
        gen forXweight = foreign*weight
        reg price foreign weight forXweight
//endex

/*txt
{pstd}The main advantage of factor variables is that now Stata knows
wich variables "belong" together, and can use that information in 
{cmd:margins}{p_end}

{pstd}Factor variables are documented in {help fvvarlist}{p_end}
txt*/

//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  Plotting predicted outcome

/*txt
{pstd}We have a model with a different parabola for foreign and domestic cars{p_end}

{pstd}The easiest way to interpret this model is to look at the predictions{p_end}
txt*/

//ex
        graph drop _all
	    sysuse auto, clear
        reg price c.weight##c.weight##i.foreign
        margins, at(weight=(1800(200)4800)) over(foreign)
        marginsplot ,                ///
            name(margins1, replace)
//endex
//graph margins1
/*txt
{pstd}It woud be nicer to display the confidence interval as a area{p_end}
txt*/
//ex
       qui margins, at(weight=(1800(200)4800)) over(foreign)
        marginsplot,                ///
            recastci(rarea)         ///
            name(margins2, replace)
//endex
//graph margins2
/*txt
{pstd}We need to change the look of the area{p_end}
txt*/

//ex
        qui margins, at(weight=(1800(200)4800)) over(foreign)
        marginsplot,                 ///
            recastci(rarea)          ///
            ciopts(astyle(ci))       ///
            name(margins3, replace)
//endex
//graph margins3

/*txt
{pstd}
The confidence intervals overlap, we can make all visibile by making them 
opaque.
txt*/

//ex
       qui margins, at(weight=(1800(200)4800)) over(foreign)
        marginsplot,                 ///
            recastci(rarea)          ///
            ciopts(astyle(ci)        ///
                   acolor(%50))      ///
            name(margins4, replace)
//endex
//graph margins4

/*txt
{pstd}We can suppress the symbols{p_end}
txt*/

//ex
        qui margins, at(weight=(1800(200)4800)) over(foreign)
        marginsplot,                 ///
            recastci(rarea)          ///
            ciopts(astyle(ci)        ///
                   acolor(%50))      ///
            plotopts(msymbol(i))     ///
            name(margins5,replace)
//endex
//graph margins5
/*txt
{pstd}But now we need to distinguish between the groups by changing the looks of 
the lines{p_end}
txt*/

//ex
        qui margins, at(weight=(1800(200)4800)) over(foreign)
        marginsplot,                 ///
           recastci(rarea)           ///
           ciopts(astyle(ci)         ///
                  acolor(%50))       ///
           plotopts(msymbol(i))      ///
           plot1opt(lpattern(dash))  ///
           name(margins6, replace)
//endex
//graph margins6

/*txt
{pstd}We can add axis labels{p_end}
txt*/

//ex
        qui margins, at(weight=(1800(200)4800)) over(foreign)
        marginsplot,                 ///
           recastci(rarea)           ///
           ciopts(astyle(ci)         ///
                  acolor(%50))       ///
           plotopts(msymbol(i))      ///
           plot1opt(lpattern(dash))  ///
           xlab(2000(500)4500)       ///
           name(margins7, replace)
//endex
//graph margins7

/*txt
{pstd}and change their format{p_end}
txt*/

//ex
        qui margins, at(weight=(1800(200)4800)) over(foreign)
        marginsplot,                 ///
           recastci(rarea)           ///
           ciopts(astyle(ci)         ///
                  acolor(%50))       ///
           plotopts(msymbol(i))      ///
           plot1opt(lpattern(dash))  ///
           xlab(2000(500)4500)       ///
           ylab(, format(%9.0gc))    ///
           name(margins8, replace)
//endex
//graph margins8
/*txt
{pstd}We don't have to plot the predictions, we can also plot the effects{p_end}
txt*/

//ex
        sysuse nlsw88, clear
        gen byte black = race == 2 if race < .
        reg wage c.ttl_exp##c.ttl_exp i.black grade i.south
        margins, dydx(ttl_exp)        ///
            at(ttl_exp=(0(2)28))      
        marginsplot , yline(0)        ///
            name(margins9, replace)
//endex
//graph margins9

//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  What can go wrong?

/*txt
{pstd}Sometimes the wrong variable appears on the x-axis and the graph looks
terrible{p_end}
txt*/

//ex
        graph drop _all
        sysuse auto, clear
        reg price c.weight##c.weight##i.foreign
        margins, at(foreign=(0/1) weight=(1800(200)4800)) 
        marginsplot, name(wrong1, replace)
//endex
//graph wrong1
/*txt
{pstd}You can control which variable is on the x-axis using the {cmd:xdim()} option{p_end}
txt*/

//ex
        qui margins, at(foreign=(0/1) weight=(1800(200)4800)) 
        marginsplot, xdim(weight) name(corr1, replace)
//endex
//graph corr1

/*txt
{pstd}With the {cmd:over()} option the average predicted wage is computed in each group.{p_end}

{pstd}So differences between union and non-union members can occur due to their membership
status or because unionmembers differ with respect to their race, where they live and their 
experience.{p_end}

{pstd}So the graph represents both the effect of union and grade but also composition effects{p_end}

{pstd}You can see that because the lines are not as straight as you would expect from
a regression line{p_end}
txt*/

//ex
        sysuse nlsw88, clear
        reg wage grade ttl_exp tenure i.union i.south i.race
        margins, over(grade union)
        marginsplot, name(wrong2, replace)
//endex
//graph wrong2
/*txt
{pstd}Here is how you avoid showing the composition effect:{p_end}
txt*/

//ex
        margins, over(grade union) ///
            at(ttl_exp=12 tenure=10 south=0 race=1)
        marginsplot, name(corr2, replace)
//endex
//graph corr2
/*txt
{center:{bf:Try it yourself}}

{pstd}
Previously we used {help predictnl} to create predicted wage for different values of 
ttl_exp, while keeping race, grade, and union constant, and the 95% confidence
interval around it. Use {cmd:margins} and {cmd:marginsplot} to create that same
graph
txt*/


//ex
sysuse nlsw88, clear
poisson wage c.ttl_exp##c.ttl_exp i.race grade i.union, vce(robust) irr
//endex

/*txt
{pstd}
//ho_ignore {stata doedit marginsplot_sol.do : Solution}
txt*/
//apcodefile marginsplot_sol.do

//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  Logit

/*txt
{pstd}{cmd:margins} and {cmd:marginsplot} are most useful when dealing with non-linear models{p_end}
txt*/

//ex
        graph drop _all
        sysuse nlsw88, clear
        gen high = occupation < 3 if occupation < .
        logit union grade i.high i.south i.race
        margins, at(grade=(0 4 6/18)) over(high)
        marginsplot, name(prob, replace)
//endex
//graph prob
/*txt
{pstd}With a bit of trickery we can also show the effect of on the odds of union membership{p_end}
txt*/

//ex
        margins, at(grade=(0 4 6/18)) ///
            over(high) expression(exp(xb()))
        
        marginsplot,                   ///
            yscale(log)                ///
            ylab(.01 .05 .1 .5 1)      ///
            ytitle("odds (log scale)") ///
            name(odds, replace)
//endex
//graph odds
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  Interactions

/*txt
{pstd}{cmd:margins} and {cmd:marginsplot} are also useful to make sense of interactions{p_end}
txt*/

//ex
        graph drop _all
        sysuse nlsw88, clear
        reg wage c.grade##c.ttl_exp tenure i.union i.south i.race
        
        margins, ///
            at(grade=(0 4 6/18) ttl_exp=(0 5 10 20) ///
               tenure=10 south=0 race=1)
        marginsplot, xdim(grade) name(pred, replace)
        
        margins, dydx(grade) ///
        at(ttl_exp=(0(2)28) ///
               tenure=10 south=0 race=1)
        marginsplot, name(eff, replace)
//endex
//graph pred
//graph eff
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title  3D margins

/*txt
{pstd}We can use the {cmd:_marg_save} command to store the results from the {cmd:margins} 
command in a seperate dataset.{p_end} 

{pstd}We can then use that dataset to plot the results in any way we like{p_end}

{pstd}For higher order interactions you quickly end up wanting a 3D graph{p_end}
txt*/

//ex
        graph drop _all
        sysuse nlsw88, clear
        gen black = race == 2 if race < 3
        reg wage c.ttl_exp##c.grade##i.black
        margins, dydx(black) at(grade=(0(2)18) ttl_exp=(0(4)28))
        _marg_save, saving(temp, replace)
        use temp, clear
        twoway contour _margin _at1 _at2, ccut(-6(.5)1)  ///
           ztitle(effect of black) name(margins3d, replace)
//endex
//graph margins3d
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title More complex interactions

/*txt
{pstd}
We could look at the effect of the mother being a homemaker on the children's 
education

{pstd}
This effect will likely

{pmore} 
increase when the father has a better job

{pmore} 
decrease if the mother could get a better job

{pmore}
increase if the mother has a higher level of education
txt*/

//ex
use ieo, replace
replace misei = 0 if home == 1

reg edyears i.home##c.medyears fedyears misei i.home##c.fisei
//endex

/*txt
{pstd}
The main effect of homemaker refers to

{pmore}
a mother with the lowest level of education

{pmore}
if she works, she would get the lowest status job

{pmore}
the father has the lowest status job

{pstd}
The effect of homemaker increases as the father gets a higher status job

{pstd}
The effect of homemaker increases as the mother gets a level of education

{pstd}
The effect of homemaker decreases as the mother can get a higher status job

{pstd}
Lets plot the effect of homemake for all combinations of fahter's and mother's 
occupation for two different educational levels

{pstd}
Notice that the relationship between {it:home} and {it:misei} is not captured by
the factor variables, so now we cannot use {cmd:margins}

{pstd}
These are two contour plots side by side

{pstd}
It is convenient to start with a new dataset that contains only those observations.
txt*/

//ex
drop _all
set obs 17
gen misei = cond(_n<17,(_n-1)*5, 77)
expand 17
bys misei : gen fisei = cond(_n<17,(_n-1)*5, 77)
expand 2
bys misei fisei : gen medyears = cond(_n==1, 1.25, 10)
by  misei fisei : gen meduc = _n // notice no sort
label define meduc 1 "Realschule" 2 "University"
label val meduc meduc

gen double eff = _b[1.home]                     + ///
                 medyears*_b[1.home#c.medyears] + ///
                 fisei*_b[1.home#c.fisei]       - ///
                 misei*_b[misei] 
//endex

/*txt
{pstd}
We can now return the occupational status to their original scale, in case there
are members in the audience who are familiar with ISEI
txt*/

//ex
//return to original scale
replace misei = misei + 13
replace fisei = fisei + 13
//endex

//ex
twoway contour eff misei fisei, by(meduc) name(home1, replace)
//endex
//graph home1
/*txt
{pstd}
What do those colors mean?
txt*/

//ex
twoway contour eff misei fisei,                         ///
    by(meduc, clegend(on)) name(home2, replace)
//endex
//graph home2

/*txt
{pstd}
Lets get rid of the white space around the graphs, and the note
txt*/

//ex
twoway contour eff misei fisei,                         ///
    by(meduc, clegend(on) note(""))                     ///  
    xlab(20(20)80)                                      ///  
    ylab(20(20)80)                                      ///
    name(home3, replace)
//endex
//graph home3

/*txt
{pstd}
Better, but there is still a bit more white than needed
txt*/

//ex
twoway contour eff misei fisei,                         ///
    by(meduc, clegend(on) note(""))                     ///  
    xlab(20(20)80)                                      ///  
    ylab(20(20)80)                                      ///
    plotregion(margin(zero))                            ///
    name(home4)
//endex
//graph home4

/*txt
{pstd}
Mother's and father's occupational status are measured on the same scale, so it
would be nice if the graphs were square
txt*/

//ex
twoway contour eff misei fisei,                         ///
    by(meduc, clegend(on) note(""))                     ///  
    xlab(20(20)80)                                      ///  
    ylab(20(20)80)                                      ///
    aspect(1)                                           /// 
    plotregion(margin(zero))                            ///
    name(home5, replace)
//endex
//graph home5

/*txt
{pstd}
Can't we show a bit more detail and use different shades of blue for negative 
effects and different shades of red for positive effects?
txt*/

//ex
twoway contour eff misei fisei,                         ///
    by(meduc, clegend(on) note(""))                     ///  
    ccuts(-2(.5)2)                                      ///  
    scolor(blue) ecolor(red) crule(hue)                 ///   
    xlab(20(20)80)                                      ///  
    ylab(20(20)80)                                      ///
    aspect(1)                                           /// 
    plotregion(margin(zero)) scheme(s2color)            ///
    name(home6, replace)
//endex
//graph home6

/*txt
{pstd}
You can also explicitly choose the colors. I find www.http://colorbrewer2.org a 
useful resource for that.

{pstd}
However, it seems that this does not play well with the {cmd:by()} option, 
especially if one of the colors does not appear in the first graph. Something
that seems to work is first create a graph in which you specify only the colors 
for the first graph, and than create a graph that specifies all colors.
txt*/

//ex
twoway contour eff misei fisei,                         ///
    by(meduc, clegend(on) note(""))                     ///  
    ccuts(-2(.5)2)                                      ///  
    cc("  5, 48, 97" " 33,102,172" " 67,147,195"        ///
       "146,197,222" "209,229,240" "253,219,199"        ///
       "244,165,130" "214, 96, 77" "178, 24, 43"        ///
       )                                                ///    
    xlab(20(20)80)                                      ///  
    ylab(20(20)80)                                      ///
    aspect(1)                                           /// 
    plotregion(margin(zero)) 
	
twoway contour eff misei fisei,                         ///
    by(meduc, clegend(on) note(""))                     ///  
    ccuts(-2(.5)2)                                      ///  
    cc("  5, 48, 97" " 33,102,172" " 67,147,195"        ///
       "146,197,222" "209,229,240" "253,219,199"        ///
       "244,165,130" "214, 96, 77" "178, 24, 43"        ///
       "103,  0, 31")                                   ///   
    xlab(20(20)80)                                      ///  
    ylab(20(20)80)                                      ///
    aspect(1)                                           /// 
    plotregion(margin(zero))                            ///
    name(home7, replace)
//endex
//graph home7

/*txt
{pstd}
Lets add axis titles 
txt*/

//ex
twoway contour eff misei fisei,                         ///
    by(meduc, clegend(on) note(""))                     ///  
    ccuts(-2(.5)2)                                      ///  
    cc("  5, 48, 97" " 33,102,172" " 67,147,195"        ///
       "146,197,222" "209,229,240" "253,219,199"        ///
       "244,165,130" "214, 96, 77" "178, 24, 43"        ///
       "103,  0, 31")                                   ///       
    xtitle(Father's occupational status)                ///
    ytitle(Mother's occupational status)                ///
    ztitle(effect of homemaker)                         ///        
    xlab(20(20)80)                                      ///  
    ylab(20(20)80)                                      ///
    aspect(1)                                           /// 
    plotregion(margin(zero))                            ///
    name(home8, replace)
//endex

/*txt
{pstd}
Lets add some cominations of occupations as a reference
txt*/

//ex
twoway contour eff misei fisei,                         ///
    by(meduc, clegend(on) note(""))                     ///  
    ccuts(-2(.5)2)                                      ///  
    cc("  5, 48, 97" " 33,102,172" " 67,147,195"        ///
       "146,197,222" "209,229,240" "253,219,199"        ///
       "244,165,130" "214, 96, 77" "178, 24, 43"        ///
       "103,  0, 31")                                   ///        
    xtitle(Father's occupational status)                ///
    ytitle(Mother's occupational status)                ///
    ztitle(effect of homemaker)                         ///        
    xlab(20(20)80)                                      ///  
    ylab(20(20)80)                                      ///
    aspect(1)                                           /// 
    plotregion(margin(zero))                        ||  ///
    scatteri 38 88 (11) "nurse, doctor"                 ///
             29 30 (12) "hairdresser, cook"             ///
             77 77 (6)  "prof, prof",                   ///
    name(home9, replace)
//endex
//graph home9

/*txt
{pstd}
The font of the axis title and the labels on the z-axis seem a bit too large
txt*/

//ex
twoway contour eff misei fisei,                         ///
    by(meduc, clegend(on) note(""))                     ///  
    ccuts(-2(.5)2)                                      ///  
    cc("  5, 48, 97" " 33,102,172" " 67,147,195"        ///
       "146,197,222" "209,229,240" "253,219,199"        ///
       "244,165,130" "214, 96, 77" "178, 24, 43"        ///
       "103,  0, 31")                                   ///       
    xtitle(Father's occupational status, size(*.8))     ///
    ytitle(Mother's occupational status, size(*.8))     ///
    ztitle(effect of homemaker, size(*.8))              ///        
    zlabel(,labsize(*.8))                               ///      
    xlab(20(20)80)                                      ///  
    ylab(20(20)80)                                      ///
    aspect(1)                                           /// 
    plotregion(margin(zero))                         || ///
    scatteri 38 88 (11) "nurse, doctor"                 ///
             29 30 (12) "hairdresser, cook"             ///
             77 77 (6)  "prof, prof"   ,                ///
    name(home10, replace)
//endex
//graph home10
//endslide ---------------------------------------------------------------------
